//*************+***************+***************+***************+***************+
//
//	SEKONIC
//	Device control header
//
//	FileName	: SkDvSrOptionApi.h
//	CPU			: x86
//	Compiler	: Microsoft Visual C++ 2010
//
//*************+***************+***************+***************+***************+
//	2020.10.15	for SR-8000HYBRID
//	2013.04.30	add Barcord reader option Api
//	2012.09.06	Option Api
//*************+***************+***************+***************+***************+
#ifndef	INCLUDE_SKDVSROPTIONAPI_HEADER			// Multi include of a header is prevented.
#define	INCLUDE_SKDVSROPTIONAPI_HEADER

#pragma once


#include "SkDvSrSeriesPrm.h"


//*************+***************+***************+***************+***************+
#ifdef __cplusplus
extern "C" {
#endif


//*************+***************+***************+***************+***************+
//
// Barcode reader : Acquisition of reading configration
//
//		Acquires the barcode reader reading conditions stored in the library.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		pBcrConf		Specify the pointer of the structure for storing the barcode reader reading condition.
//		pBcrConfEx		for SR-8000HYBRID
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		The barcode reader reading conditions to be acquired are the contents retained in this library.
//		The barcode reader reading conditions held by this library are stored in the argument pBcrConf.
//		It does not communicate with the device.
//		If you want to get the contents set in the device such as immediately after startup, 
//		call the SkDv_ReqInit function or SkDv_ReqGetBcrConf function in advance.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_GetBcrConf(SkDvHandle hSkDevice, SK_DV_OPT_BCR_CONF* pBcrConf);

SkDvStatus	WINAPI	SkDv_GetBcrConfEx(SkDvHandle hSkDevice, SK_DV_OPT_BCR_CONF_EX* pBcrConfEx);

//*************+***************+***************+***************+***************+
//
// Barcode reader : Reading configration setting
//
//		Set the barcode reader reading conditions in the library.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		pBcrConf		Specify the pointer of the structure in which the barcode reader reading condition is stored.
//		pBcrConfEx		for SR-8000HYBRID
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		If the device information has not been acquired, it communicates with the device and stores the device information in the library.
//		The barcode reader reading condition specified by the argument pBcrConf is checked according to the contents of the device information, 
//		and if there is a problem with the value, an error is returned.
//		If there is no error, the barcode reader reading condition is stored in the library.
//		The bar code reader reading condition settings can be set in the device by communication by executing the "read request" or the SkDv_ReqSetBcrConf function.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_SetBcrConf(SkDvHandle hSkDevice, SK_DV_OPT_BCR_CONF* pBcrConf);

SkDvStatus	WINAPI	SkDv_SetBcrConfEx(SkDvHandle hSkDevice, SK_DV_OPT_BCR_CONF_EX* pBcrConfEx);


//*************+***************+***************+***************+***************+
//
// Barcode reader : Read configration acquisition communication request
//
//		Communicates with the device to acquire the barcode reader reading conditions.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		Communicates to acquire barcode reader reading conditions and holds it inside the library.
//		The command to use is as follows. For details of the command, refer to the attached "Command Reference".
//		-Command "BC"
//		-Command "IB"
//		-Command "BI"
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqGetBcrConf(SkDvHandle hSkDevice);


//*************+***************+***************+***************+***************+
//
// Barcode reader : Reading configration setting communication request
//
//		Communicates with the device to set the barcode reader reading conditions.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		Set the barcode reader reading conditions held inside the library on the device.
//		The command to use is the same as the "SkDv_ReqGetBcrConf" function.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqSetBcrConf(SkDvHandle hSkDevice);


//*************+***************+***************+***************+***************+
//
// Barcode reader : Quantity data acquisition communication request
//
//		Acquire the number of read barcodes by communication.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		piReadCount		Specify the address of the variable to store the number of barcodes read.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		The number of barcodes read by the read request is acquired by the barcode data request "BD".
//		It cannot be acquired when it is read by the continuous reading request.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqGetBcrDataCount(SkDvHandle hSkDevice, int* piReadCount);


//*************+***************+***************+***************+***************+
//
// Barcode reader : Read data acquisition communication request
//
//		Acquires the data of the specified number of the read barcode by communication.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		iIndex			Specify the index number of the read barcode starting from 1.
//		pcBcType		Specify the pointer of the variable to store the barcode type specified by iIndex.
//		pszBarcode		Specify the address of the buffer for storing the barcode data specified by iIndex.
//		piDataLen		Specify the byte size of the buffer for storing the barcode data specified by iIndex.
//						Stores data in the buffer specified by pszBarcode up to the specified size.
//						After executing the process, the required buffer size is stored.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		The barcode data read by the read request is acquired by the barcode data request "BD".
//		It cannot be acquired when it is read by the continuous reading request.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqGetBcrData(SkDvHandle hSkDevice, int iIndex, char* pcBcType, char* pszBarcode, int* piDataLen);



//*************+***************+***************+***************+***************+
//
// Printer : Print condition acquisition
//
//		Acquires the printer print conditions stored in the library.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		pPrnConf		Specify the pointer of the structure for storing the printer print conditions.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		The printer print conditions to be acquired are the contents retained in this library.
//		The printer print conditions held by this library are stored in the argument pPrnConf.
//		It does not communicate with the device.
//		If you want to get the contents set in the device such as immediately after startup, 
//		call the SkDv_ReqInit function or SkDv_ReqGetPrinterConf function in advance.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_GetPrinterConf(SkDvHandle hSkDevice, SK_DV_OPT_PRN_CONF* pPrnConf);


//*************+***************+***************+***************+***************+
//
// Printer : Print condition setting
//
//		Set the printer print conditions in the library.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		pPrnConf		Specifies the pointer of the structure that stores the print conditions of the printer.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_SetPrinterConf(SkDvHandle hSkDevice, SK_DV_OPT_PRN_CONF* pPrnConf);


//*************+***************+***************+***************+***************+
//
// Printer print character setting communication request
//
//		Set the characters you want to print on the device.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		pString			Specify the pointer of the character string that stores the character you want to print
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqPrintString(SkDvHandle hSkDevice, char* pString);


//*************+***************+***************+***************+***************+
//
// Printer	: Acquisition of print conditions Communication request
//
//		Communicates with the device to acquire the print conditions of the printer.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqGetPrinterConf(SkDvHandle hSkDevice);


//*************+***************+***************+***************+***************+
//
// Printer	: Print condition setting communication request
//
//		Communicates with the device to set the printing conditions of the printer.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqSetPrinterConf(SkDvHandle hSkDevice);




#ifdef __cplusplus
}
#endif

#endif											// Multi include of a header is prevented.

