//

#include "stdafx.h"
#include <winnls.h>
#include <mmsystem.h>
#include "EditLogBox.h"

#pragma comment(lib, "winmm.lib")

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif


#define ONELINE_LENGTH_MAX		1024

//#define OPT_OSVERSIONINFOEX

typedef void (WINAPI *PGNSI)(LPSYSTEM_INFO); 



/////////////////////////////////////////////////////////////////////////////
// CEditLogBox

//*************+***************+***************+***************+***************+
CEditLogBox::CEditLogBox()
{
	m_iListNumber	= 1024;

	InitializeCriticalSection(&m_csWriteLog);
}

CEditLogBox::~CEditLogBox()
{
	DeleteCriticalSection(&m_csWriteLog);
}


BEGIN_MESSAGE_MAP(CEditLogBox, CListBox)
	//{{AFX_MSG_MAP(CEditLogBox)
		// 
	//}}AFX_MSG_MAP
	ON_WM_CREATE()
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////


int CEditLogBox::OnCreate(LPCREATESTRUCT lpCreateStruct)
{
	if (CEdit::OnCreate(lpCreateStruct) == -1)
		return -1;


	return 0;
}

BOOL CEditLogBox::PreCreateWindow(CREATESTRUCT& cs)
{

	return CEdit::PreCreateWindow(cs);
}

BOOL CEditLogBox::Create(DWORD dwStyle, const RECT& rect, CWnd* pParentWnd, UINT nID)
{

	return CEdit::Create(dwStyle, rect, pParentWnd, nID);
}

BOOL CEditLogBox::CreateEx(DWORD dwExStyle, LPCTSTR lpszClassName, LPCTSTR lpszWindowName, DWORD dwStyle, const RECT& rect, CWnd* pParentWnd, UINT nID, LPVOID lpParam)
{

	return CEdit::CreateEx(dwExStyle, lpszClassName, lpszWindowName, dwStyle, rect, pParentWnd, nID, lpParam);
}

//*************+***************+***************+***************+***************+
void CEditLogBox::PreSubclassWindow() 
{
	CEdit::ModifyStyle(0   ,ES_AUTOHSCROLL | ES_MULTILINE | ES_READONLY | WS_VSCROLL | WS_HSCROLL  );
	CEdit::SetReadOnly();

	CEdit::PreSubclassWindow();
	CEdit::SetLimitText(1024 * m_iListNumber);
	
	//m_NewFont.CreatePointFont(90, _T("lr SVbN"));
	//SetFont(&m_NewFont);

	//LogStartLog();
	//LogOsVersionInfo();
	//LogCpuName();
	//LogChipset();
	//LogRamSize();
	//LogComputerName();
}


//*************+***************+***************+***************+***************+
void CEditLogBox::ClearLog()
{
//	EnterCriticalSection(&m_csWriteLog);

	CEdit::SetWindowTextA("");

//	LeaveCriticalSection(&m_csWriteLog);
}


//*************+***************+***************+***************+***************+
void	CEditLogBox::AddInfo(void)
{
	LogStartLog();
	LogOsVersionInfo();
	LogCpuName();
	LogChipset();
	LogRamSize();
	LogComputerName();
}


//*************+***************+***************+***************+***************+
void CEditLogBox::AddLog(const char *pstrLog)
{
//	EnterCriticalSection(&m_csWriteLog);

	CEdit::SetSel(0x7fffffff, 0x7fffffff, TRUE);
	CEdit::ReplaceSel( pstrLog );
	CEdit::SetSel(0x7fffffff, 0x7fffffff, TRUE);
	CEdit::ReplaceSel( _T("\r\n") );
	CEdit::SetSel(0x7fffffff, 0x7fffffff, FALSE);

	LimitListNumber();

//	LeaveCriticalSection(&m_csWriteLog);
}

//*************+***************+***************+***************+***************+
void	CEditLogBox::ClearSplit()
{
	GetSplitTime();
}

//*************+***************+***************+***************+***************+
void CEditLogBox::AddSplit(TCHAR *pFormat, ... )
{
	TCHAR		szLogString[ONELINE_LENGTH_MAX];
	int			iHeaderLen;
	va_list		ap ;
	DWORD		dwSplitTime;
	
	dwSplitTime	= GetSplitTime();
	if(1000000 > dwSplitTime )
		iHeaderLen	= sprintf_s( szLogString, sizeof(szLogString), _T("[+%6ldms]")		, dwSplitTime );
	else
		iHeaderLen	= sprintf_s( szLogString, sizeof(szLogString), _T("[+Over  ms]")	, dwSplitTime );

	va_start( ap, pFormat );
	vsprintf_s( &szLogString[iHeaderLen], sizeof(szLogString) - iHeaderLen, pFormat, ap);
	va_end(ap) ;
	
	AddLog( szLogString );
}

//*************+***************+***************+***************+***************+
void CEditLogBox::AddComment(TCHAR *pFormat, ... )
{
	TCHAR		szLogString[ONELINE_LENGTH_MAX];
	int			iHeaderLen;
	va_list		ap ;
	
	iHeaderLen	= sprintf_s( szLogString, sizeof(szLogString), _T("[         ]:"));

	va_start( ap, pFormat );
	_vstprintf_s( &szLogString[iHeaderLen], sizeof(szLogString) - iHeaderLen, pFormat, ap);
	va_end(ap) ;
	
	AddLog( szLogString );
}

//*************+***************+***************+***************+***************+
void CEditLogBox::SetLogNumber(int iNumber)
{
	if(10 > iNumber)	iNumber	= 10;
	m_iListNumber	= iNumber;
	LimitListNumber();
	CEdit::SetLimitText(1024 * m_iListNumber);
}

//*************+***************+***************+***************+***************+
void CEditLogBox::LimitListNumber()
{
	while( CEdit::GetLineCount() > m_iListNumber)
	{
		CEdit::SetSel(0, CEdit::LineLength(0)+1, TRUE);
		CEdit::ReplaceSel((LPCTSTR)_T(""));
	}
	CEdit::SetSel(0x7fffffff, 0x7fffffff, FALSE);

	//int nStartChar, nEndChar;
	//CEdit::GetSel(nStartChar, nEndChar);
	//CEdit::SetSel(nEndChar, nEndChar, FALSE);
}

//*************+***************+***************+***************+***************+
DWORD CEditLogBox::GetSplitTime()
{
	DWORD			dwResTime;
	
//	dwResTime	= GetTickCount() - dwOldTime;
	dwResTime	= timeGetTime() - m_dwOldTime;
	
	m_dwOldTime	+= dwResTime;
	return( dwResTime );
}


//*************+***************+***************+***************+***************+
bool CEditLogBox::CopyClipboard()
{
	CString	strText;

	CEdit::GetWindowText(strText);

	if( strText.IsEmpty() )
		return FALSE;

	if( !::OpenClipboard(NULL) )
		return FALSE;

	int iStrLen = strText.GetLength() + 1;
	HGLOBAL hMem = ::GlobalAlloc(GMEM_FIXED, iStrLen);
	LPTSTR pMem = (LPTSTR)hMem;
	::lstrcpy(pMem, (LPCTSTR)strText);

	::EmptyClipboard();
	::SetClipboardData(CF_TEXT, hMem);
	::CloseClipboard();

	return TRUE;
}


//*************+***************+***************+***************+***************+

//-----+-------+-------+-------+-------+-------+-------+-------+
bool CEditLogBox::LogStartLog()
{
	char		szLogString[ONELINE_LENGTH_MAX];
	SYSTEMTIME	today;

	GetSplitTime();
	GetLocalTime( &today );
	sprintf_s( szLogString, sizeof(szLogString),
			_T("[#%04d/%02d/%02d %02d:%02d:%02d.%03d]") ,
			 today.wYear, today.wMonth, today.wDay, today.wHour, today.wMinute, today.wSecond, today.wMilliseconds );
	AddLog(szLogString);
	return( true );
}


bool CEditLogBox::LogComputerName()
{
	return( true );
}


bool CEditLogBox::LogCpuName()
{
	return( true );
}


bool CEditLogBox::LogRamSize()
{
	return( true );
}


bool CEditLogBox::LogChipset()
{
	return( true );
}


bool CEditLogBox::LogOsVersionInfo()
{
	return( true );
}


bool CEditLogBox::SaveLog(char *pstrFilename)
{
	return TRUE;
}


